==> nextcloud-app-news-1:25.2.0-1.0-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/news/l10n/uk.js <==
OC.L10N.register(
    "news",
    {
    "Request failed, network connection unavailable!" : "Запит не вдався, немає мережевого з'єднання!",
    "Request unauthorized. Are you logged in?" : "Запит не авторизований. Ви увійшли в систему?",
    "Request forbidden. Are you an administrator?" : "Запит заборонено. Ви адміністратор?",
    "Token expired or app not enabled! Reload the page!" : "Термін дії токена закінчився або застосунок не увімкнено! Оновіть сторінку!",
    "Internal server error! Please check your data/nextcloud.log file for additional information!" : "Внутрішня помилка сервера! Щоб отримати додаткову інформацію, перевірте файл data/nextcloud.log!",
    "Request failed, Nextcloud is in currently in maintenance mode!" : "Помилка запиту, Nextcloud зараз у режимі обслуговування!",
    "News feeds" : "Стрічки новин",
    "Unread articles" : "Непрочитані статті",
    "News" : "Новини",
    "Download" : "Звантажити",
    "Close" : "Закрити",
    "Web address" : "Веб адреса",
    "No folder" : "Відсутній каталог",
    "Folder name" : "Назва каталогу",
    "Username" : "Ім'я користувача",
    "Password" : "Пароль",
    "Feed exists already!" : "Стрічка вже існує !",
    "New folder" : "Новий каталог",
    "Folder exists already!" : "Каталог вже існує !",
    "HTTP Basic Auth credentials must be stored unencrypted! Everyone with access to the server or database will be able to access them!" : "Облікові дані HTTP Basic Auth повинні зберігатися незашифрованими! Усі, хто має доступ до сервера або бази даних, зможуть отримати до них доступ!",
    "Credentials" : "Облікові дані",
    "Subscribe" : "Підписатися",
    "Last job ran {relativeTime}." : "Останнє завдання виконано {relativeTime}.",
    "Maximum read count per feed" : "Максимальна кількість статей для стрічки",
    "Maximum redirects" : "Максимум перенаправлень",
    "Feed fetcher timeout" : "Час очікування для завантажувача стрічки",
    "Explore Service URL" : "URL сервісу дослідження",
    "Update interval" : "Інтервал оновлення",
    "Successfully updated news configuration" : "Конфігурацію новин успішно оновлено",
    "Use system cron for updates" : "Використовуйте системний cron для оновлень",
    "Defines the maximum amount of articles that can be read per feed which will not be deleted by the cleanup job; if old articles reappear after being read, increase this value; negative values such as -1 will turn this feature off." : "Визначає максимальну кількість статей, які можна прочитати на канал, які не будуть видалені під час завдання очищення; якщо старі статті знову з’являються після прочитання, збільште це значення; від'ємні значення, такі як -1, вимкнуть цю функцію.",
    "Move" : "Перемістити",
    "User Name" : "Ім'я користувача",
    "Share" : "Спільний доступ",
    "Share with" : "Поділитися з",
    "Mark read" : "Позначити як прочитане",
    "All articles" : "Всі статті",
    "Starred" : "Із зірочкою",
    "Explore" : "Дослідити",
    "Settings" : "Налаштування",
    "Keyboard shortcuts" : "Сполучення клавіш",
    "Disable mark read through scrolling" : "Вимкнути читання поміток при прокрутці",
    "Show all articles" : "Показати всі статті",
    "Reverse ordering (oldest on top)" : "Зворотний порядок (найстаріші зверху)",
    "Vertical" : "Вертикальний",
    "Horizontal" : "Горизонтальний",
    "Rename Folder" : "Перейменувати каталог",
    "Are you sure you want to delete?" : "Ви впевнені, що хочете видалити?",
    "Rename" : "Перейменувати",
    "Delete" : "Вилучити",
    "Rename Feed" : "Перейменувати стрічку",
    "Unpin from top" : "Зняти закріплення",
    "Pin to top" : "Закріпити нагорі",
    "Newest first" : "Новіші спочатку",
    "Oldest first" : "Старіші спочатку",
    "Enable full text" : "Увімкнути контекстний",
    "Disable full text" : "Вимкнути контекстний",
    "Toggle star article" : "Позначити статтю",
    "Mark unread" : "Позначити як не прочитане",
    "by" : "по",
    "from" : "З",
    "Play audio" : "Відтворення аудіо",
    "Download audio" : "Звантажити аудіо",
    "Download video" : "Звантажити відео",
    "Open website" : "Відкрити веб-сайт",
    "Keep article unread" : "Залишити статтю непрочитаною",
    "Toggle keep current article unread" : "Залишити статтю непрочитаною",
    "Remove keep article unread" : "Позначити статтю як прочитану",
    "{num} seconds" : "{num} секунд",
    "{num} minutes ago" : "{num} хвилин тому",
    "{num} hours ago" : "{num} годин тому",
    "{num} days ago" : "{num} днів тому",
    "{num} months ago" : "{num} місяців тому",
    "{num} years ago" : "{num} років тому",
    "Title" : "Заголовок",
    "Not available" : "Не доступно",
    "Keyboard shortcut" : "Сполучення клавіш",
    "Action" : "Дія ",
    "Jump to next article" : "Наступна стаття",
    "Jump to previous article" : "Попередня стаття",
    "right" : "праворуч",
    "left" : "ліворуч",
    "Star article and jump to next one" : "Позначити статтю та перейти до наступної",
    "Open article in new tab" : "Відкрити статтю в новій вкладці",
    "Refresh" : "Оновити",
    "Load next feed" : "Завантажити наступну стрічку",
    "Load previous feed" : "Звантажити попередню стрічку",
    "Load previous folder" : "Звантажити попередній каталог",
    "Load next folder" : "Завантажити наступний каталог",
    "Scroll to active navigation entry" : "Перехід до обраного елементу",
    "Shift" : "Shift",
    "How to set up the operating system cron" : "Як налаштувати cron операційної системи",
    "Install and set up a faster parallel updater that uses the News app's update API" : "Встановіть та налаштуйте швидший паралельний засіб оновлення, який використовуватиме API оновлення застосунку \"Новини\"",
    "No articles available" : "Немає доступних статей",
    "No unread articles available" : "Немає непрочитаних записів",
    "Star article" : "Позначити статтю",
    "Unstar article" : "Зняти зірочку зі статті",
    "Share on social media" : "Поділитися у соціяльних медіях",
    "Description" : "Опис",
    "Toggle expand article in compact view" : "Переключити статтю в компактний режим",
    "Mark current article's feed/folder read" : "Позначити поточну видачу/каталог зі статтями прочитаними",
    "Folder" : "Каталог",
    "Go back" : "Повернутися назад",
    "New Folder" : "Новий каталог",
    "Create" : "Створити",
    "Update failed more than 50 times" : "Помилка оновлення понад 50 разів",
    "Deleted feed" : "Вилучена стрічка",
    "Undo delete feed" : "Скасувати вилучення стрічки",
    "Menu" : "Меню",
    "Dismiss" : "Припинити",
    "Collapse" : "Згорнути",
    "Deleted folder" : "Вилучений каталог",
    "Undo delete folder" : "Скасувати вилучення каталогу",
    "Compact view" : "Компактний вигляд",
    "Expand articles on key navigation" : "Розширенні артикули під час навігації по ключах",
    "Subscriptions (OPML)" : "Підписки (OPML)",
    "Import" : "Імпорт",
    "Export" : "Експорт",
    "Error when importing: OPML is does neither contain feeds nor folders" : "Помилка під час імпорту: OPML не містить ані каналів, ані папок",
    "Unread/Starred Articles" : "Непрочитані/Вибрані статті",
    "Error when importing: file does not contain valid JSON" : "Помилка при імпорті: файл не містить дійсний JSON",
    "Help" : "Допомога",
    "Documentation" : "Документація",
    "Report a bug" : "Повідомити про помилку"
},
"nplurals=4; plural=(n % 1 == 0 && n % 10 == 1 && n % 100 != 11 ? 0 : n % 1 == 0 && n % 10 >= 2 && n % 10 <= 4 && (n % 100 < 12 || n % 100 > 14) ? 1 : n % 1 == 0 && (n % 10 ==0 || (n % 10 >=5 && n % 10 <=9) || (n % 100 >=11 && n % 100 <=14 )) ? 2: 3);");

==> nextcloud-app-news-1:26.0.1-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/news/l10n/uk.js <==
OC.L10N.register(
    "news",
    {
    "News feeds" : "Стрічки новин",
    "Unread articles" : "Непрочитані статті",
    "News" : "Новини",
    "Download" : "Звантажити",
    "Close" : "Закрити",
    "Web address" : "Веб адреса",
    "No folder" : "Відсутній каталог",
    "Folder name" : "Назва каталогу",
    "Username" : "Ім'я користувача",
    "Password" : "Пароль",
    "Feed exists already!" : "Стрічка вже існує !",
    "New folder" : "Новий каталог",
    "Folder exists already!" : "Каталог вже існує !",
    "HTTP Basic Auth credentials must be stored unencrypted! Everyone with access to the server or database will be able to access them!" : "Облікові дані HTTP Basic Auth повинні зберігатися незашифрованими! Усі, хто має доступ до сервера або бази даних, зможуть отримати до них доступ!",
    "Credentials" : "Облікові дані",
    "Subscribe" : "Підписатися",
    "Successfully updated news configuration" : "Конфігурацію новин успішно оновлено",
    "Last job ran {relativeTime}." : "Останнє завдання виконано {relativeTime}.",
    "Maximum read count per feed" : "Максимальна кількість статей для стрічки",
    "Maximum redirects" : "Максимум перенаправлень",
    "Feed fetcher timeout" : "Час очікування для завантажувача стрічки",
    "Explore Service URL" : "URL сервісу дослідження",
    "Update interval" : "Інтервал оновлення",
    "Use system cron for updates" : "Використовуйте системний cron для оновлень",
    "Defines the maximum amount of articles that can be read per feed which will not be deleted by the cleanup job; if old articles reappear after being read, increase this value; negative values such as -1 will turn this feature off." : "Визначає максимальну кількість статей, які можна прочитати на канал, які не будуть видалені під час завдання очищення; якщо старі статті знову з’являються після прочитання, збільште це значення; від'ємні значення, такі як -1, вимкнуть цю функцію.",
    "Move" : "Перемістити",
    "User Name" : "Ім'я користувача",
    "Share" : "Спільний доступ",
    "Share with" : "Поділитися з",
    "Default" : "Типово",
    "Vertical" : "Вертикальний",
    "Horizontal" : "Горизонтальний",
    "Rename Folder" : "Перейменувати каталог",
    "Are you sure you want to delete?" : "Ви впевнені, що хочете видалити?",
    "Mark read" : "Позначити як прочитане",
    "All articles" : "Всі статті",
    "Starred" : "Із зірочкою",
    "Explore" : "Дослідити",
    "Settings" : "Налаштування",
    "Documentation" : "Документація",
    "Keyboard shortcuts" : "Сполучення клавіш",
    "Disable mark read through scrolling" : "Вимкнути читання поміток при прокрутці",
    "Show all articles" : "Показати всі статті",
    "Reverse ordering (oldest on top)" : "Зворотний порядок (найстаріші зверху)",
    "Rename" : "Перейменувати",
    "Delete" : "Вилучити",
    "Rename Feed" : "Перейменувати стрічку",
    "Unpin from top" : "Зняти закріплення",
    "Pin to top" : "Закріпити нагорі",
    "Newest first" : "Новіші спочатку",
    "Oldest first" : "Старіші спочатку",
    "Enable full text" : "Увімкнути контекстний",
    "Disable full text" : "Вимкнути контекстний",
    "Previous" : "Назад",
    "Next" : "Далі",
    "Toggle star article" : "Позначити статтю",
    "Mark unread" : "Позначити як не прочитане",
    "by" : "по",
    "Play audio" : "Відтворення аудіо",
    "Download audio" : "Звантажити аудіо",
    "Download video" : "Звантажити відео",
    "Open website" : "Відкрити веб-сайт",
    "Keep article unread" : "Залишити статтю непрочитаною",
    "Toggle keep current article unread" : "Залишити статтю непрочитаною",
    "Remove keep article unread" : "Позначити статтю як прочитану",
    "Not available" : "Не доступно",
    "Please wait" : "Будь ласка, зачекайте",
    "Title" : "Заголовок",
    "Keyboard shortcut" : "Сполучення клавіш",
    "Action" : "Дія ",
    "Jump to next article" : "Наступна стаття",
    "Jump to previous article" : "Попередня стаття",
    "right" : "праворуч",
    "left" : "ліворуч",
    "Star article and jump to next one" : "Позначити статтю та перейти до наступної",
    "Open article in new tab" : "Відкрити статтю в новій вкладці",
    "Refresh" : "Оновити",
    "Load next feed" : "Завантажити наступну стрічку",
    "Load previous feed" : "Звантажити попередню стрічку",
    "Load previous folder" : "Звантажити попередній каталог",
    "Load next folder" : "Завантажити наступний каталог",
    "Scroll to active navigation entry" : "Перехід до обраного елементу",
    "Shift" : "Shift",
    "How to set up the operating system cron" : "Як налаштувати cron операційної системи",
    "Install and set up a faster parallel updater that uses the News app's update API" : "Встановіть та налаштуйте швидший паралельний засіб оновлення, який використовуватиме API оновлення застосунку \"Новини\""
},
"nplurals=4; plural=(n % 1 == 0 && n % 10 == 1 && n % 100 != 11 ? 0 : n % 1 == 0 && n % 10 >= 2 && n % 10 <= 4 && (n % 100 < 12 || n % 100 > 14) ? 1 : n % 1 == 0 && (n % 10 ==0 || (n % 10 >=5 && n % 10 <=9) || (n % 100 >=11 && n % 100 <=14 )) ? 2: 3);");
